[Groonga-commit] droonga/droonga-http-server at 80be995 [master] Use "receive_host" instead of "receiveR_host" for simplicity

Back to archive index

Piro / YUKI Hiroshi null+****@clear*****
Tue Sep 23 19:39:48 JST 2014


Piro / YUKI Hiroshi	2014-09-23 19:39:48 +0900 (Tue, 23 Sep 2014)

  New Revision: 80be995244d5dd8b03d9310b02d26eafd65d6213
  https://github.com/droonga/droonga-http-server/commit/80be995244d5dd8b03d9310b02d26eafd65d6213

  Message:
    Use "receive_host" instead of "receiveR_host" for simplicity

  Modified files:
    bin/droonga-http-server-configure
    lib/default-configs.js
    lib/server-options.js
    sample/droonga-http-server.yaml

  Modified: bin/droonga-http-server-configure (+1 -1)
===================================================================
--- bin/droonga-http-server-configure    2014-09-23 19:37:55 +0900 (8892026)
+++ bin/droonga-http-server-configure    2014-09-23 19:39:48 +0900 (4c427ca)
@@ -312,7 +312,7 @@ function writeNewConfigs() {
   engineConfigs.port            = configValues.droongaEnginePort;
   engineConfigs.default_dataset = configValues.defaultDataset;
   engineConfigs.tag             = configValues.tag;
-  engineConfigs.receiver_host   = configValues.receiveHostName;
+  engineConfigs.receive_host    = configValues.receiveHostName;
   configs.engine = engineConfigs;
 
   var configYaml = yaml.safeDump(configs);

  Modified: lib/default-configs.js (+2 -2)
===================================================================
--- lib/server-options.js    2014-09-23 19:37:55 +0900 (952da9f)
+++ lib/server-options.js    2014-09-23 19:39:48 +0900 (099be9f)
@@ -17,7 +17,7 @@ options.droongaEngineHostName = defaultConfigs.engine.host;
 options.droongaEnginePort     = defaultConfigs.engine.port;
 options.tag                   = defaultConfigs.engine.tag;
 options.defaultDataset        = defaultConfigs.engine.default_dataset;
-options.receiveHostName       = defaultConfigs.engine.receiver_host;
+options.receiveHostName       = defaultConfigs.engine.receive_host;
 
 function intOption(newValue, oldValue) {
   return parseInt(newValue);

  Modified: sample/droonga-http-server.yaml (+1 -1)
===================================================================
--- sample/droonga-http-server.yaml    2014-09-23 19:37:55 +0900 (c611d4d)
+++ sample/droonga-http-server.yaml    2014-09-23 19:39:48 +0900 (a70a17e)
@@ -9,4 +9,4 @@ engine:
   port:            10031
   default_dataset: Default
   tag:             droonga
-  receiver_host:   192.168.0.10
+  receive_host:    192.168.0.10
-------------- next part --------------
HTML����������������������������...
Download 



More information about the Groonga-commit mailing list
Back to archive index
--- lib/default-configs.js    2014-09-23 19:37:55 +0900 (0cf3a39)
+++ lib/default-configs.js    2014-09-23 19:39:48 +0900 (7b2dae1)
@@ -79,11 +79,11 @@ define(configs, 'engine.host',            engineConfigs.host);
 define(configs, 'engine.port',            engineConfigs.port);
 define(configs, 'engine.tag',             engineConfigs.tag);
 define(configs, 'engine.default_dataset', 'Default');
 // We can use the host name of the droonga-engine as the receiver host
 // of the http server, because this computer works as a droonga-engine
 // node and it is guaranteed that this computer can be accessed with
 // the host name.
-define(configs, 'engine.receiver_host',   engineConfigs.host);
+define(configs, 'engine.receive_host',    engineConfigs.host);
 
 return configs;
 }
@@ -79,11 +79,11 @@ define(configs, 'engine.host',            engineConfigs.host);
 define(configs, 'engine.tag',             engineConfigs.tag);
 define(configs, 'engine.default_dataset', 'Default');
-// We can use the host name of the droonga-engine as the receiver host
+// We can use the host name of the droonga-engine as the receive host
 // of the http server, because this computer works as a droonga-engine
 // node and it is guaranteed that this computer can be accessed with

  Modified: lib/server-options.js (+1 -1)
===================================================================